@@ -59,7 +59,7 @@ pub struct Cli {
     /// Like --form, but force a multipart/form-data request even without files.
     ///
     /// Overrides both --json and --form.
-    #[clap(short = 'm', long, overrides_with_all = &["json", "form"])]
+    #[clap(long, overrides_with_all = &["json", "form"])]
     pub multipart: bool,
 
     /// Pass raw request data without extra processing.
@@ -99,13 +99,22 @@ Defaults to \"format\" if the NO_COLOR env is set and to \"none\" if stdout is n
     #[clap(long, value_name = "MIME_TYPE")]
     pub response_mime: Option<String>,
 
-    /// String specifying what the output should contain.
-    ///
-    /// Use "H" and "B" for request header and body respectively,
-    /// and "h" and "b" for response header and body.
-    ///
-    /// Example: --print=Hb
-    #[clap(short = 'p', long, value_name = "FORMAT")]
+    /// String specifying what the output should contain
+    #[clap(
+        short = 'p',
+        long,
+        value_name = "FORMAT",
+        long_help = "\
+String specifying what the output should contain
+
+    'H' request headers
+    'B' request body
+    'h' response headers
+    'b' response body
+    'm' response metadata
+
+Example: --print=Hb"
+    )]
     pub print: Option<Print>,
 
     /// Print only the response headers. Shortcut for --print=h.
@@ -116,14 +125,20 @@ Defaults to \"format\" if the NO_COLOR env is set and to \"none\" if stdout is n
     #[clap(short = 'b', long)]
     pub body: bool,
 
+    /// Print only the response metadata. Shortcut for --print=m.
+    #[clap(short = 'm', long)]
+    pub meta: bool,
+
     /// Print the whole request as well as the response.
     ///
     /// Additionally, this enables --all for printing intermediary
     /// requests/responses while following redirects.
     ///
+    /// Using verbose twice i.e. -vv will print the response metadata as well.
+    ///
     /// Equivalent to --print=HhBb --all.
-    #[clap(short = 'v', long)]
-    pub verbose: bool,
+    #[clap(short = 'v', long, parse(from_occurrences))]
+    pub verbose: usize,
 
     /// Show any intermediary requests/responses while following redirects with --follow.
     #[clap(long)]
@@ -347,19 +362,11 @@ Defaults to \"format\" if the NO_COLOR env is set and to \"none\" if stdout is n
     ///         Add a JSON property (--json) or form field (--form) to
     ///         the request body.
     ///
-    ///     key=@filename
-    ///         Add a JSON property (--json) or form field (--form) from a
-    ///         file to the request body.
-    ///
     ///     key:=value
     ///         Add a field with a literal JSON value to the request body.
     ///
     ///         Example: "numbers:=[1,2,3] enabled:=true"
     ///
-    ///     key:=@filename
-    ///         Add a field with a literal JSON value from a file to the
-    ///         request body.
-    ///
     ///     key@filename
     ///         Upload a file (requires --form or --multipart).
     ///
@@ -380,6 +387,8 @@ Defaults to \"format\" if the NO_COLOR env is set and to \"none\" if stdout is n
     ///     header;
     ///         Add a header with an empty value.
     ///
+    /// An "@" prefix can be used to read a value from a file. For example: "x-api-key:@api-key.txt".
+    ///
     /// A backslash can be used to escape special characters, e.g. "weird\:key=value".
     ///
     /// To construct a complex JSON object, the REQUEST_ITEM's key can be set to a JSON path instead of a field name.
@@ -440,7 +449,7 @@ impl Cli {
                 // instead of here.
                 Self::into_app().print_help().unwrap();
                 println!(
-                    "\nRun `{} help` for more complete documentation.",
+                    "\nRun \"{} help\" for more complete documentation.",
                     env!("CARGO_PKG_NAME")
                 );
                 safe_exit();
@@ -510,12 +519,7 @@ impl Cli {
 
         cli.process_relations(&matches)?;
 
-        cli.url = construct_url(
-            &raw_url,
-            cli.default_scheme.as_deref(),
-            cli.request_items.query(),
-        )
-        .map_err(|err| {
+        cli.url = construct_url(&raw_url, cli.default_scheme.as_deref()).map_err(|err| {
             app.error(
                 ErrorKind::ValueValidation,
                 format!("Invalid <URL>: {}", err),
@@ -531,7 +535,7 @@ impl Cli {
 
     /// Set flags that are implied by other flags and report conflicting flags.
     fn process_relations(&mut self, matches: &clap::ArgMatches) -> clap::Result<()> {
-        if self.verbose {
+        if self.verbose > 0 {
             self.all = true;
         }
         if self.curl_long {
@@ -662,13 +666,12 @@ fn parse_method(method: &str) -> Option<Method> {
 fn construct_url(
     url: &str,
     default_scheme: Option<&str>,
-    query: Vec<(&str, &str)>,
 ) -> std::result::Result<Url, url::ParseError> {
     let mut default_scheme = default_scheme.unwrap_or("http://").to_string();
     if !default_scheme.ends_with("://") {
         default_scheme.push_str("://");
     }
-    let mut url: Url = if let Some(url) = url.strip_prefix("://") {
+    let url: Url = if let Some(url) = url.strip_prefix("://") {
         // Allow users to quickly convert a URL copied from a clipboard to xh/HTTPie command
         // by simply adding a space before `://`.
         // Example: https://example.org -> https ://example.org
@@ -680,14 +683,6 @@ fn construct_url(
     } else {
         url.parse()?
     };
-    if !query.is_empty() {
-        // If we run this even without adding pairs it adds a `?`, hence
-        // the .is_empty() check
-        let mut pairs = url.query_pairs_mut();
-        for (name, value) in query {
-            pairs.append_pair(name, value);
-        }
-    }
     Ok(url)
 }
 
@@ -834,7 +829,7 @@ fn generate_manpages(mut app: clap::Command, rest_args: Vec<String>) -> Error {
                 header.push(roman("] | "));
                 header.push(italic("TOKEN"));
             } else {
-                header.push(italic(&value.join(" ")));
+                header.push(italic(value.join(" ")));
             }
         }
         let mut body = vec![];
@@ -972,23 +967,26 @@ pub struct Print {
     pub request_body: bool,
     pub response_headers: bool,
     pub response_body: bool,
+    pub response_meta: bool,
 }
 
 impl Print {
     pub fn new(
-        verbose: bool,
+        verbose: usize,
         headers: bool,
         body: bool,
+        meta: bool,
         quiet: bool,
         offline: bool,
         buffer: &Buffer,
     ) -> Self {
-        if verbose {
+        if verbose > 0 {
             Print {
                 request_headers: true,
                 request_body: true,
                 response_headers: true,
                 response_body: true,
+                response_meta: verbose > 1,
             }
         } else if quiet {
             Print {
@@ -996,6 +994,7 @@ impl Print {
                 request_body: false,
                 response_headers: false,
                 response_body: false,
+                response_meta: false,
             }
         } else if offline {
             Print {
@@ -1003,6 +1002,7 @@ impl Print {
                 request_body: true,
                 response_headers: false,
                 response_body: false,
+                response_meta: false,
             }
         } else if headers {
             Print {
@@ -1010,6 +1010,7 @@ impl Print {
                 request_body: false,
                 response_headers: true,
                 response_body: false,
+                response_meta: false,
             }
         } else if body || !buffer.is_terminal() {
             Print {
@@ -1017,6 +1018,15 @@ impl Print {
                 request_body: false,
                 response_headers: false,
                 response_body: true,
+                response_meta: false,
+            }
+        } else if meta {
+            Print {
+                request_headers: false,
+                request_body: false,
+                response_headers: false,
+                response_body: false,
+                response_meta: true,
             }
         } else {
             Print {
@@ -1024,6 +1034,7 @@ impl Print {
                 request_body: false,
                 response_headers: true,
                 response_body: true,
+                response_meta: false,
             }
         }
     }
@@ -1036,6 +1047,7 @@ impl FromStr for Print {
         let mut request_body = false;
         let mut response_headers = false;
         let mut response_body = false;
+        let mut response_meta = false;
 
         for char in s.chars() {
             match char {
@@ -1043,6 +1055,7 @@ impl FromStr for Print {
                 'B' => request_body = true,
                 'h' => response_headers = true,
                 'b' => response_body = true,
+                'm' => response_meta = true,
                 char => return Err(anyhow!("{:?} is not a valid value", char)),
             }
         }
@@ -1052,6 +1065,7 @@ impl FromStr for Print {
             request_body,
             response_headers,
             response_body,
+            response_meta,
         };
         Ok(p)
     }
@@ -1070,13 +1084,18 @@ impl FromStr for Timeout {
     type Err = anyhow::Error;
 
     fn from_str(sec: &str) -> anyhow::Result<Timeout> {
-        let pos_sec: f64 = match sec.parse::<f64>() {
-            Ok(sec) if sec.is_sign_positive() => sec,
-            _ => return Err(anyhow!("Invalid seconds as connection timeout")),
-        };
-
-        let dur = Duration::from_secs_f64(pos_sec);
-        Ok(Timeout(dur))
+        match f64::from_str(sec) {
+            Ok(s) if !s.is_nan() => {
+                if s.is_sign_negative() {
+                    Err(anyhow!("Connection timeout is negative"))
+                } else if s >= Duration::MAX.as_secs_f64() || s.is_infinite() {
+                    Err(anyhow!("Connection timeout is too big"))
+                } else {
+                    Ok(Timeout(Duration::from_secs_f64(s)))
+                }
+            }
+            _ => Err(anyhow!("Connection timeout is not a valid number")),
+        }
     }
 }
 
